#include <sdl/sdl.h>

#pragma comment(lib,"sdl.lib")
#pragma comment(lib,"sdlmain.lib")

SDL_Surface* Charger(const char* fic)
{
	SDL_Surface* res = SDL_LoadBMP(fic);
	if (res==NULL)
	{
		printf("Erreur chargement %s\n",fic);
		exit(-1);
	}
	return res;
}

int KeyHit()
{
	SDL_Event e;
	if (SDL_PollEvent(&e))
		if (e.type == SDL_KEYDOWN)
			return 1;
	return 0;
}

int main(int argc,char** argv)
{
	SDL_Surface* homer,*screen;
	SDL_Init(SDL_INIT_VIDEO);
	screen=SDL_SetVideoMode(800,600,32,SDL_SWSURFACE|SDL_DOUBLEBUF);  
	homer=Charger("homer.bmp");
	SDL_SetColorKey(homer,SDL_SRCCOLORKEY ,SDL_MapRGBA(homer->format,255,0,255,0));
	while(!KeyHit())
	{
		SDL_Rect R;
		R.x = rand()%800;
		R.y = rand()%600;
		SDL_BlitSurface(homer,NULL,screen,&R);
		SDL_Flip(screen);
	}
	SDL_FreeSurface(homer);
	SDL_Quit();
	return 0;
}

/*!F

	Un petit exemple pour montrer qu'on peut, une fois une image charge, la blitter autant de fois qu'on le souhaite.

	Un pige classique est de charger une image dans la boucle principale (donc  chaque itration !) et de la blitter.
	Cela met le disque dur  rude preuve d'une part, et cre des ralentissements d'autre part.
	Il arrive mme que certaines personnes ne librent pas les images qu'elles rechargent  chaque fois dans la boucle
	principale : cela entraine une monte de mmoire jusqu' faire ramer le systme, ou au plantage de leur programme.

	Expliquons rapidement ce programme :
	Je charge une fois pour toutes l'image Homer. Je dis que sa colorkey est le violet (255,0,255)

	Puis je la blit en boucle dans le while, tout simplement...
	Charge une fois, blitte plein de fois.

	J'ai fait deux petites fonctions :
	- Charger, a charge une image, et quitte avec un message d'erreur explicite si le chargement a chou, car
	  il faut toujours tester ses retours de chargement.

	- KeyHit, dit si oui ou non on a appuy sur une touche. Se comprend facilement.
!*/

/*!E
	No explanations yet.
!*/

/*
titre: Multiple Blit.
titreE: Multiple Blit.
meta: C;SDL;blit
metaE: C;SDL;blit
desc : Charger une fois l'image, la blitter autant qu'on le souhaite.
descE : Loading an image once, and blit it several times.
cle  : SDL_LoadBMP,SDL_BlitSurface
linkA: homer.bmp
parag: 
parag: 2. La librairie SDL.
parag: 2.1. Blit et mouvements.
paragE: 
paragE: 2. SDL library.
paragE: 2.1. Blit and movings.
*/
